@@ -1,9 +1,9 @@
 use strict;
 package Dist::Zilla::App::Tester;
 {
-  $Dist::Zilla::App::Tester::VERSION = '4.300020';
+  $Dist::Zilla::App::Tester::VERSION = '4.300030';
 }
-use base 'App::Cmd::Tester';
+use parent 'App::Cmd::Tester::CaptureExternal';
 use App::Cmd::Tester 0.306 (); # result_class, ->app
 # ABSTRACT: testing library for Dist::Zilla::App
 
@@ -46,7 +46,7 @@ sub test_dzil {
 {
   package Dist::Zilla::App::Tester::Result;
 {
-  $Dist::Zilla::App::Tester::Result::VERSION = '4.300020';
+  $Dist::Zilla::App::Tester::Result::VERSION = '4.300030';
 }
   BEGIN { our @ISA = qw(App::Cmd::Tester::Result); }
 
@@ -85,6 +85,7 @@ sub test_dzil {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -93,7 +94,7 @@ Dist::Zilla::App::Tester - testing library for Dist::Zilla::App
 
 =head1 VERSION
 
-version 4.300020
+version 4.300030
 
 =head1 AUTHOR
 
@@ -101,10 +102,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
