@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ManifestSkip;
 {
-  $Dist::Zilla::Plugin::ManifestSkip::VERSION = '4.300020';
+  $Dist::Zilla::Plugin::ManifestSkip::VERSION = '4.300030';
 }
 # ABSTRACT: decline to build files that appear in a MANIFEST.SKIP-like file
 use Moose;
@@ -8,7 +8,6 @@ with 'Dist::Zilla::Role::FilePruner';
 
 use namespace::autoclean;
 
-use ExtUtils::Manifest 1.54; # public maniskip routine
 use Moose::Autobox;
 
 
@@ -16,12 +15,35 @@ has skipfile => (is => 'ro', required => 1, default => 'MANIFEST.SKIP');
 
 sub prune_files {
   my ($self) = @_;
+  my $files = $self->zilla->files;
 
-  my $skipfile = $self->zilla->root->file( $self->skipfile );
-  return unless -f $skipfile;
-  my $skip = ExtUtils::Manifest::maniskip($skipfile);
+  my $skipfile_name = $self->skipfile;
+  my ($skipfile) = grep { $_->name eq $skipfile_name } $files->flatten;
+  unless (defined $skipfile) {
+    $self->log_debug([ 'file %s not found', $skipfile_name ]);
+    return;
+  }
 
-  for my $file ($self->zilla->files->flatten) {
+  my $content = $skipfile->content;
+
+  # If the content has been generated in memory or changed from disk,
+  # create a temp file with the content.
+  # (Unfortunately maniskip can't read from a string ref)
+  my $fh;
+  if (! -f $skipfile_name || (-s $skipfile_name) != length($content)) {
+    $fh = File::Temp->new;
+    $skipfile_name = $fh->filename;
+    $self->log_debug([ 'create temporary %s', $skipfile_name ]);
+    print $fh $content;
+    close $fh;
+  }
+
+  require ExtUtils::Manifest;
+  ExtUtils::Manifest->VERSION('1.54');
+
+  my $skip = ExtUtils::Manifest::maniskip($skipfile_name);
+
+  for my $file ($files->flatten) {
     next unless $skip->($file->name);
 
     $self->log_debug([ 'pruning %s', $file->name ]);
@@ -36,6 +58,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -44,7 +67,7 @@ Dist::Zilla::Plugin::ManifestSkip - decline to build files that appear in a MANI
 
 =head1 VERSION
 
-version 4.300020
+version 4.300030
 
 =head1 DESCRIPTION
 
@@ -77,10 +100,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
