@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaConfig;
 {
-  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.300020';
+  $Dist::Zilla::Plugin::MetaConfig::VERSION = '4.300030';
 }
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
 use Moose;
@@ -24,6 +24,10 @@ sub metadata {
       (keys %$config ? (config => $config) : ()),
   };
 
+  $dump->{perl} = {
+    version => $],
+  };
+
   for my $plugin (@{ $self->zilla->plugins }) {
     my $config = $plugin->dump_config;
 
@@ -41,8 +45,8 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -51,7 +55,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 4.300020
+version 4.300030
 
 =head1 DESCRIPTION
 
@@ -62,6 +66,9 @@ package, and version will be included.  Plugins may augment their
 implementation of the L<Dist::Zilla::Role::ConfigDumper> role methods to add
 more data to this dump.
 
+More information may be added to the top-level of this metadata as time goes
+on.
+
 =head1 SEE ALSO
 
 Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
@@ -72,10 +79,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
