@@ -1,19 +1,34 @@
 package Dist::Zilla::Plugin::PodSyntaxTests;
 {
-  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.300020';
+  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.300030';
 }
 # ABSTRACT: a release test for Pod syntax
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::PrereqSource';
 
 use namespace::autoclean;
 
 
+
+# Register the release test prereq as a "develop requires"
+# so it will be listed in "dzil listdeps --author"
+sub register_prereqs {
+  my ($self) = @_;
+
+  $self->zilla->register_prereqs(
+    {
+      type  => 'requires',
+      phase => 'develop',
+    },
+    'Test::Pod' => '1.41',
+  );
+}
+
+
 __PACKAGE__->meta->make_immutable;
 1;
 
-
-
 =pod
 
 =head1 NAME
@@ -22,7 +37,7 @@ Dist::Zilla::Plugin::PodSyntaxTests - a release test for Pod syntax
 
 =head1 VERSION
 
-version 4.300020
+version 4.300030
 
 =head1 DESCRIPTION
 
@@ -31,20 +46,21 @@ following files:
 
   xt/release/pod-syntax.t   - a standard Test::Pod test
 
+L<Test::Pod> C<1.41> will be added as a C<develop requires> dependency.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 ___[ xt/release/pod-syntax.t ]___
 #!perl
