@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PruneFiles;
 {
-  $Dist::Zilla::Plugin::PruneFiles::VERSION = '4.300006';
+  $Dist::Zilla::Plugin::PruneFiles::VERSION = '4.300030';
 }
 # ABSTRACT: prune arbirary files from the dist
 use Moose;
@@ -53,6 +53,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -61,7 +62,7 @@ Dist::Zilla::Plugin::PruneFiles - prune arbirary files from the dist
 
 =head1 VERSION
 
-version 4.300006
+version 4.300030
 
 =head1 SYNOPSIS
 
@@ -93,16 +94,22 @@ This is an arrayref of filenames to be pruned from the distribution.
 This is an arrayref of regular expressions and files matching any of them,
 will be pruned from the distribution.
 
+=head1 SEE ALSO
+
+Dist::Zilla plugins:
+L<PruneCruft|Dist::Zilla::Plugin::PruneCruft>,
+L<GatherDir|Dist::Zilla::Plugin::GatherDir>,
+L<ManifestSkip|Dist::Zilla::Plugin::ManifestSkip>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
