@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Filter;
 {
-  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.300020';
+  $Dist::Zilla::PluginBundle::Filter::VERSION = '4.300030';
 }
 # ABSTRACT: use another bundle, with some plugins removed
 use Moose;
@@ -35,7 +35,12 @@ sub bundle_config {
 
   $bundle = Dist::Zilla::Util->expand_config_package_name($bundle);
 
-  Class::MOP::load_class($bundle);
+  my $load_opts = {};
+  if( my $v = $config->{filter}->{version} ){
+    $load_opts->{'-version'} = $v;
+  }
+
+  Class::MOP::load_class($bundle, $load_opts);
 
   my @plugins = $bundle->bundle_config({
     name    => $section->{name}, # not 100% sure about this -- rjbs, 2010-03-06
@@ -59,6 +64,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -67,7 +73,7 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 4.300020
+version 4.300030
 
 =head1 SYNOPSIS
 
@@ -99,10 +105,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
